/*
 * Copyright (c) 2019 UPLEX Nils Goroll Systemoptimierung
 * All rights reserved
 *
 * Author: Geoffrey Simmons <geoffrey.simmons@uplex.de>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

package apiclient

import (
	"fmt"

	api_v1 "k8s.io/api/core/v1"
	meta_v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	utilruntime "k8s.io/apimachinery/pkg/util/runtime"
)

func (client *Client) podEvent(evtType, reason, msgFmt string,
	args ...interface{}) {

	if client.pod == nil {
		noop := meta_v1.GetOptions{}
		pod, err := client.client.CoreV1().Pods(client.podNs).
			Get(client.podName, noop)
		if err != nil {
			e := fmt.Errorf("Cannot retrieve Pod object for %s/%s,"+
				" will not generate event(%s, %s): %v",
				client.podNs, client.podName, evtType, reason,
				err)
			utilruntime.HandleError(e)
			return
		}
		client.pod = pod
	}
	client.recorder.Eventf(client.pod, evtType, reason, msgFmt, args...)
}

// PodInfoEvent generates an Event with type "Normal" for the current Pod.
func (client *Client) PodInfoEvent(reason, msgFmt string, args ...interface{}) {
	client.podEvent(api_v1.EventTypeNormal, reason, msgFmt, args...)
}

// PodWarnEvent generates an Event with type "Warning" for the current Pod.
func (client *Client) PodWarnEvent(reason, msgFmt string, args ...interface{}) {
	client.podEvent(api_v1.EventTypeWarning, reason, msgFmt, args...)
}
